@@ -31,7 +31,6 @@ if TYPE_CHECKING:
         CompliantSeriesOrNativeExprAny,
         EvalNames,
         EvalSeries,
-        ScalarKwargs,
     )
     from narwhals._utils import Implementation, Version, _LimitedContext
     from narwhals.dtypes import DType
@@ -201,12 +200,9 @@ class CompliantSelector(
     CompliantExpr[FrameT, SeriesOrExprT], Protocol38[FrameT, SeriesOrExprT]
 ):
     _call: EvalSeries[FrameT, SeriesOrExprT]
-    _window_function: None
     _function_name: str
-    _depth: int
     _implementation: Implementation
     _version: Version
-    _scalar_kwargs: ScalarKwargs
 
     @classmethod
     def from_callables(
@@ -218,14 +214,10 @@ class CompliantSelector(
     ) -> Self:
         obj = cls.__new__(cls)
         obj._call = call
-        obj._window_function = None
-        obj._depth = 0
-        obj._function_name = "selector"
         obj._evaluate_output_names = evaluate_output_names
         obj._alias_output_names = None
         obj._implementation = context._implementation
         obj._version = context._version
-        obj._scalar_kwargs = {}
         return obj
 
     @property
