@@ -7,14 +7,11 @@ import pytest
 import narwhals as nw
 from narwhals._utils import Implementation
 from narwhals.dependencies import get_cudf, get_modin, get_polars
-from tests.utils import PANDAS_VERSION, POLARS_VERSION, Constructor, assert_equal_data
+from tests.utils import POLARS_VERSION, Constructor, assert_equal_data
 
 if TYPE_CHECKING:
     from types import ModuleType
 
-if PANDAS_VERSION < (1,):  # pragma: no cover
-    pytest.skip(allow_module_level=True)
-
 
 data = {"a": [1, 2], "b": [3, 4]}
 
